@@ -1,19 +1,9 @@
-/* Copyright (C) 1997 Mathias Mueller   <in5y158@public.uni-hamburg.de>
- * Copyright (C) 2006 Mauricio Piacentini   <mauricio@tabuleiro.com>
- *
- * Kmahjongg is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA. */
+/*
+    SPDX-FileCopyrightText: 1997 Mathias Mueller <in5y158@public.uni-hamburg.de>
+    SPDX-FileCopyrightText: 2006 Mauricio Piacentini <mauricio@tabuleiro.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef FRAMEIMAGE_H
 #define FRAMEIMAGE_H
@@ -21,10 +11,12 @@
 // Qt
 #include <QWidget>
 
+// LibKMahjongg
+#include <KMahjonggTileset>
+#include <KMahjonggBackground>
+
 // KMahjongg
 #include "boardlayout.h"
-#include "kmahjonggbackground.h"
-#include "kmahjonggtileset.h"
 
 class QPixmap;
 class QPixmap;
